==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/V1SubjectRulesReviewStatusFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface V1SubjectRulesReviewStatusFluent<A extends V1SubjectRulesReviewStatusFluent<A>> extends Fluent<A>{


    public String getEvaluationError();
    public A withEvaluationError(String evaluationError);
    public Boolean hasEvaluationError();
    public Boolean isIncomplete();
    public A withIncomplete(Boolean incomplete);
    public Boolean hasIncomplete();
    public A withNewIncomplete(boolean arg1);
    public A withNewIncomplete(String arg1);
    public A addToNonResourceRules(int index,V1NonResourceRule item);
    public A setToNonResourceRules(int index,V1NonResourceRule item);
    public A addToNonResourceRules(V1NonResourceRule... items);
    public A addAllToNonResourceRules(Collection<V1NonResourceRule> items);
    public A removeFromNonResourceRules(V1NonResourceRule... items);
    public A removeAllFromNonResourceRules(Collection<V1NonResourceRule> items);
    
/**
 * This method has been deprecated, please use method buildNonResourceRules instead.
 * @return The buildable object.
 */
@Deprecated public List<V1NonResourceRule> getNonResourceRules();
    public List<V1NonResourceRule> buildNonResourceRules();
    public V1NonResourceRule buildNonResourceRule(int index);
    public V1NonResourceRule buildFirstNonResourceRule();
    public V1NonResourceRule buildLastNonResourceRule();
    public V1NonResourceRule buildMatchingNonResourceRule(io.kubernetes.client.fluent.Predicate<V1NonResourceRuleBuilder> predicate);
    public A withNonResourceRules(List<V1NonResourceRule> nonResourceRules);
    public A withNonResourceRules(V1NonResourceRule... nonResourceRules);
    public Boolean hasNonResourceRules();
    public V1SubjectRulesReviewStatusFluent.NonResourceRulesNested<A> addNewNonResourceRule();
    public V1SubjectRulesReviewStatusFluent.NonResourceRulesNested<A> addNewNonResourceRuleLike(V1NonResourceRule item);
    public V1SubjectRulesReviewStatusFluent.NonResourceRulesNested<A> setNewNonResourceRuleLike(int index,V1NonResourceRule item);
    public V1SubjectRulesReviewStatusFluent.NonResourceRulesNested<A> editNonResourceRule(int index);
    public V1SubjectRulesReviewStatusFluent.NonResourceRulesNested<A> editFirstNonResourceRule();
    public V1SubjectRulesReviewStatusFluent.NonResourceRulesNested<A> editLastNonResourceRule();
    public V1SubjectRulesReviewStatusFluent.NonResourceRulesNested<A> editMatchingNonResourceRule(io.kubernetes.client.fluent.Predicate<V1NonResourceRuleBuilder> predicate);
    public A addToResourceRules(int index,V1ResourceRule item);
    public A setToResourceRules(int index,V1ResourceRule item);
    public A addToResourceRules(V1ResourceRule... items);
    public A addAllToResourceRules(Collection<V1ResourceRule> items);
    public A removeFromResourceRules(V1ResourceRule... items);
    public A removeAllFromResourceRules(Collection<V1ResourceRule> items);
    
/**
 * This method has been deprecated, please use method buildResourceRules instead.
 * @return The buildable object.
 */
@Deprecated public List<V1ResourceRule> getResourceRules();
    public List<V1ResourceRule> buildResourceRules();
    public V1ResourceRule buildResourceRule(int index);
    public V1ResourceRule buildFirstResourceRule();
    public V1ResourceRule buildLastResourceRule();
    public V1ResourceRule buildMatchingResourceRule(io.kubernetes.client.fluent.Predicate<V1ResourceRuleBuilder> predicate);
    public A withResourceRules(List<V1ResourceRule> resourceRules);
    public A withResourceRules(V1ResourceRule... resourceRules);
    public Boolean hasResourceRules();
    public V1SubjectRulesReviewStatusFluent.ResourceRulesNested<A> addNewResourceRule();
    public V1SubjectRulesReviewStatusFluent.ResourceRulesNested<A> addNewResourceRuleLike(V1ResourceRule item);
    public V1SubjectRulesReviewStatusFluent.ResourceRulesNested<A> setNewResourceRuleLike(int index,V1ResourceRule item);
    public V1SubjectRulesReviewStatusFluent.ResourceRulesNested<A> editResourceRule(int index);
    public V1SubjectRulesReviewStatusFluent.ResourceRulesNested<A> editFirstResourceRule();
    public V1SubjectRulesReviewStatusFluent.ResourceRulesNested<A> editLastResourceRule();
    public V1SubjectRulesReviewStatusFluent.ResourceRulesNested<A> editMatchingResourceRule(io.kubernetes.client.fluent.Predicate<V1ResourceRuleBuilder> predicate);

    public interface NonResourceRulesNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1NonResourceRuleFluent<V1SubjectRulesReviewStatusFluent.NonResourceRulesNested<N>>{

        
    public N and();    public N endNonResourceRule();
}
    public interface ResourceRulesNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1ResourceRuleFluent<V1SubjectRulesReviewStatusFluent.ResourceRulesNested<N>>{

        
    public N and();    public N endResourceRule();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1SubjectRulesReviewStatusFluent.java <==
package io.kubernetes.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface V1SubjectRulesReviewStatusFluent<A extends V1SubjectRulesReviewStatusFluent<A>> extends Fluent<A>{


    public String getEvaluationError();
    public A withEvaluationError(String evaluationError);
    public Boolean hasEvaluationError();
    public A withNewEvaluationError(String arg1);
    public A withNewEvaluationError(StringBuilder arg1);
    public A withNewEvaluationError(StringBuffer arg1);
    public Boolean isIncomplete();
    public A withIncomplete(Boolean incomplete);
    public Boolean hasIncomplete();
    public A withNewIncomplete(String arg1);
    public A withNewIncomplete(boolean arg1);
    public A addToNonResourceRules(int index,V1NonResourceRule item);
    public A setToNonResourceRules(int index,V1NonResourceRule item);
    public A addToNonResourceRules(V1NonResourceRule... items);
    public A addAllToNonResourceRules(Collection<V1NonResourceRule> items);
    public A removeFromNonResourceRules(V1NonResourceRule... items);
    public A removeAllFromNonResourceRules(Collection<V1NonResourceRule> items);
    
/**
 * This method has been deprecated, please use method buildNonResourceRules instead.
 * @return The buildable object.
 */
@Deprecated public List<V1NonResourceRule> getNonResourceRules();
    public List<V1NonResourceRule> buildNonResourceRules();
    public V1NonResourceRule buildNonResourceRule(int index);
    public V1NonResourceRule buildFirstNonResourceRule();
    public V1NonResourceRule buildLastNonResourceRule();
    public V1NonResourceRule buildMatchingNonResourceRule(io.kubernetes.client.fluent.Predicate<V1NonResourceRuleBuilder> predicate);
    public Boolean hasMatchingNonResourceRule(io.kubernetes.client.fluent.Predicate<V1NonResourceRuleBuilder> predicate);
    public A withNonResourceRules(List<V1NonResourceRule> nonResourceRules);
    public A withNonResourceRules(V1NonResourceRule... nonResourceRules);
    public Boolean hasNonResourceRules();
    public V1SubjectRulesReviewStatusFluent.NonResourceRulesNested<A> addNewNonResourceRule();
    public V1SubjectRulesReviewStatusFluent.NonResourceRulesNested<A> addNewNonResourceRuleLike(V1NonResourceRule item);
    public V1SubjectRulesReviewStatusFluent.NonResourceRulesNested<A> setNewNonResourceRuleLike(int index,V1NonResourceRule item);
    public V1SubjectRulesReviewStatusFluent.NonResourceRulesNested<A> editNonResourceRule(int index);
    public V1SubjectRulesReviewStatusFluent.NonResourceRulesNested<A> editFirstNonResourceRule();
    public V1SubjectRulesReviewStatusFluent.NonResourceRulesNested<A> editLastNonResourceRule();
    public V1SubjectRulesReviewStatusFluent.NonResourceRulesNested<A> editMatchingNonResourceRule(io.kubernetes.client.fluent.Predicate<V1NonResourceRuleBuilder> predicate);
    public A addToResourceRules(int index,V1ResourceRule item);
    public A setToResourceRules(int index,V1ResourceRule item);
    public A addToResourceRules(V1ResourceRule... items);
    public A addAllToResourceRules(Collection<V1ResourceRule> items);
    public A removeFromResourceRules(V1ResourceRule... items);
    public A removeAllFromResourceRules(Collection<V1ResourceRule> items);
    
/**
 * This method has been deprecated, please use method buildResourceRules instead.
 * @return The buildable object.
 */
@Deprecated public List<V1ResourceRule> getResourceRules();
    public List<V1ResourceRule> buildResourceRules();
    public V1ResourceRule buildResourceRule(int index);
    public V1ResourceRule buildFirstResourceRule();
    public V1ResourceRule buildLastResourceRule();
    public V1ResourceRule buildMatchingResourceRule(io.kubernetes.client.fluent.Predicate<V1ResourceRuleBuilder> predicate);
    public Boolean hasMatchingResourceRule(io.kubernetes.client.fluent.Predicate<V1ResourceRuleBuilder> predicate);
    public A withResourceRules(List<V1ResourceRule> resourceRules);
    public A withResourceRules(V1ResourceRule... resourceRules);
    public Boolean hasResourceRules();
    public V1SubjectRulesReviewStatusFluent.ResourceRulesNested<A> addNewResourceRule();
    public V1SubjectRulesReviewStatusFluent.ResourceRulesNested<A> addNewResourceRuleLike(V1ResourceRule item);
    public V1SubjectRulesReviewStatusFluent.ResourceRulesNested<A> setNewResourceRuleLike(int index,V1ResourceRule item);
    public V1SubjectRulesReviewStatusFluent.ResourceRulesNested<A> editResourceRule(int index);
    public V1SubjectRulesReviewStatusFluent.ResourceRulesNested<A> editFirstResourceRule();
    public V1SubjectRulesReviewStatusFluent.ResourceRulesNested<A> editLastResourceRule();
    public V1SubjectRulesReviewStatusFluent.ResourceRulesNested<A> editMatchingResourceRule(io.kubernetes.client.fluent.Predicate<V1ResourceRuleBuilder> predicate);

    public interface NonResourceRulesNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1NonResourceRuleFluent<V1SubjectRulesReviewStatusFluent.NonResourceRulesNested<N>>{

        
    public N and();    public N endNonResourceRule();
}
    public interface ResourceRulesNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1ResourceRuleFluent<V1SubjectRulesReviewStatusFluent.ResourceRulesNested<N>>{

        
    public N and();    public N endResourceRule();
}


}
